#####################     R Code: Data Analysis     #####################
# Helwig, N.E., Sohre, N.E., Ruprecht, M.R., Guy, S.J., Lyford-Pike, S. (2017)
#   Dynamic Properties of Successful Smiles
#   Submitted to PLOS ONE (last updated March 21, 2017)


###################     DEFINE DATA PATH AND INSTALL PACKAGES     ###################

### define data path
path <- "~/Desktop/smile/"

### install and/or load 'bigsplines' package (ver 1.1-0)
if(!require(bigsplines)){
  install.packages("bigsplines")
  library("bigsplines")
}

### install and/or load 'RColorBrewerPackage' package
if(!require(RColorBrewer)){
  install.packages("RColorBrewer")
  library("RColorBrewer")
}


###################     DATA ANALYSIS: SYMMETRIC SMILES     ###################

###*### create variables and fit model ###*###

### load data
smiledata <- read.csv(paste0(path,"smiledata.csv"))
smiledata$Angle <- factor(smiledata$Angle, levels=c("low","med","high"), ordered=TRUE)
smiledata$Extent <- factor(smiledata$Extent, levels=c("low","med","high"), ordered=TRUE)
smiledata$Dental <- factor(smiledata$Dental, levels=c("low","med","high"), ordered=TRUE)

### historgrams of demographics
dev.new(width=12, height=4, noRStudioGD=TRUE)
par(mfrow=c(1,3), mar=c(5,5,4,2))
uad <- unique(smiledata[,c("subID","age","gender","drinks")])
numgender <- summary(uad$gender)
hist(uad$age[uad$gender=="F"], col="pink", border="red",
     ylim=c(0,100), xlim=c(10,90), axes=F, xlab="Age (years)",
     main="Female Ages", cex.lab=2, cex.main=3)
axis(1, at=seq(10,90,by=10), cex.axis=1.5)
axis(2, cex.axis=1.5)
text(70,95,labels=substitute(italic(n)*" = "*xx, list(xx=numgender[1])), cex=2)
box()
hist(uad$age[uad$gender=="M"], col="cyan", border="blue",
     ylim=c(0,100), xlim=c(10,90), axes=F, xlab="Age (years)",
     main="Male Ages", cex.lab=2, cex.main=3)
text(70,95,labels=substitute(italic(n)*" = "*xx, list(xx=numgender[2])), cex=2)
axis(1, at=seq(10,90,by=10), cex.axis=1.5)
axis(2, cex.axis=1.5)
box()
sumdrink <- summary(factor(uad$drinks))
hist(uad$drinks, col="gray", breaks=(seq(-1,5)+0.5),
     ylim=c(0,800), xlim=c(-1,6), axes=F, xlab="Number of Drinks",
     main="Drinks Consumed", cex.lab=2, cex.main=3)
axis(1, at=0:5, cex.axis=1.5)
axis(2, cex.axis=1.5)
text(0:5, sumdrink + 25, labels=sumdrink, cex=1.5)
box()
dev.copy2pdf(file=paste0(path,"Fig4.pdf"))

### get knot indices for smile stimuli
ixsp <- split(1:nrow(smiledata), smiledata$stimuli)
knotid <- unlist(lapply(ixsp,function(x) x[1]))

### define SSANOVA formulas
xform <- c("~ Angle*Extent*Dental + age + gender + drinks",
           "~ Angle*Extent + Angle*Dental + Extent*Dental + age + gender + drinks",
           "~ Angle*Extent + Angle*Dental + age + gender + drinks",
           "~ Angle*Extent + Extent*Dental + age + gender + drinks",
           "~ Angle*Dental + Extent*Dental + age + gender + drinks",
           "~ Angle*Extent + Dental + age + gender + drinks",
           "~ Angle*Dental + Extent + age + gender + drinks",
           "~ Angle + Extent*Dental + age + gender + drinks",
           "~ Angle + Extent + Dental + age + gender + drinks")
eforms <- paste("effective", xform)
gforms <- paste("genuine", xform)
pforms <- paste("pleasant", xform)

### fit SSANOVA models
rktypes <- list(Angle="ord", Extent="ord", Dental="ord", age="cub", gender="nom", drinks="cub")
emodlist <- gmodlist <- pmodlist <- vector("list", length(eforms))
for(k in 1:length(emodlist)){
  cat("model:",k,"\n")
  emodlist[[k]] <- bigssp(as.formula(eforms[k]), data=smiledata, nknots=knotid, 
                          type=rktypes, random=~1|subID, skip.iter=F)
  gmodlist[[k]] <- bigssp(as.formula(gforms[k]), data=smiledata, nknots=knotid, 
                          type=rktypes, random=~1|subID, skip.iter=F)
  pmodlist[[k]] <- bigssp(as.formula(pforms[k]), data=smiledata, nknots=knotid, 
                          type=rktypes, random=~1|subID, skip.iter=F)
}

### save results
save(emodlist, gmodlist, pmodlist, file=paste0(path,"smile-ssa-results.rda"))


###*### basic inference information ###*###

### collect fit statistics
einfo <- t(sapply(emodlist, function(x) x$info))
ginfo <- t(sapply(gmodlist, function(x) x$info))
pinfo <- t(sapply(pmodlist, function(x) x$info))
table2 <- cbind(einfo[,3:4],ginfo[,3:4],pinfo[,3:4])

### determine best models
c(which.min(einfo[,3]), which.min(einfo[,4]))
c(which.min(ginfo[,3]), which.min(ginfo[,4]))
c(which.min(pinfo[,3]), which.min(pinfo[,4]))

### define models for plotting
essamod <- emodlist[[1]]
gssamod <- gmodlist[[1]]
pssamod <- pmodlist[[1]]

### get individual level predictions
ehat <- predict(essamod) + essamod$blup[match(smiledata$subID,names(essamod$blup))]
ghat <- predict(gssamod) + gssamod$blup[match(smiledata$subID,names(gssamod$blup))]
phat <- predict(pssamod) + pssamod$blup[match(smiledata$subID,names(pssamod$blup))]

### R-squared without random effects
eRsqA <- cor(smiledata$effective, predict(essamod))^2
gRsqA <- cor(smiledata$genuine, predict(gssamod))^2
pRsqA <- cor(smiledata$pleasant, predict(pssamod))^2

### R-squared with random effects
eRsqB <- cor(smiledata$effective, ehat)^2
gRsqB <- cor(smiledata$genuine, ghat)^2
pRsqB <- cor(smiledata$pleasant, phat)^2

### check variance parameters
evar <- (essamod$sigma^2)*c(1,essamod$tau)
gvar <- (gssamod$sigma^2)*c(1,gssamod$tau)
pvar <- (pssamod$sigma^2)*c(1,pssamod$tau)

### check intra-class correlations
eicc <- essamod$tau / (1 + essamod$tau)
gicc <- gssamod$tau / (1 + gssamod$tau)
picc <- pssamod$tau / (1 + pssamod$tau)

### table results
table3A <- rbind(RsqA = c(eRsqA, gRsqA, pRsqA),
                 RsqB = c(eRsqB, gRsqB, pRsqB),
                 sigsq = c(evar[1],gvar[1],pvar[1]),
                 thesq = c(evar[2],gvar[2],pvar[2]),
                 icc = c(eicc, gicc, picc))


###*### plot model predictions ###*###

### load smile parameters
smileInfo <- read.csv(paste0(path,"smileInfo.csv"),row.names=1)

### get smile effect fitted values
inames <- c("Angle","Extent","Dental","Angle:Extent","Angle:Dental","Extent:Dental","Angle:Extent:Dental")
esmilefit <- predict(essamod, smileInfo[,2:4], se.fit=TRUE, include=inames, intercept=T)
gsmilefit <- predict(gssamod, smileInfo[,2:4], se.fit=TRUE, include=inames, intercept=T)
psmilefit <- predict(pssamod, smileInfo[,2:4], se.fit=TRUE, include=inames, intercept=T)

### get age effect fitted values
eage <- predict(essamod, newdata=data.frame(age=seq(18,80)), include="age", se.fit=T)
gage <- predict(gssamod, newdata=data.frame(age=seq(18,80)), include="age", se.fit=T)
page <- predict(pssamod, newdata=data.frame(age=seq(18,80)), include="age", se.fit=T)

### get gender effect fitted values
egender <- predict(essamod, newdata=data.frame(gender=c("F","M")), include="gender", se.fit=T)
ggender <- predict(gssamod, newdata=data.frame(gender=c("F","M")), include="gender", se.fit=T)
pgender <- predict(pssamod, newdata=data.frame(gender=c("F","M")), include="gender", se.fit=T)

### get drinking effect fitted values
edrink <- predict(essamod, newdata=data.frame(drinks=0:5), include="drinks", se.fit=T)
gdrink <- predict(gssamod, newdata=data.frame(drinks=0:5), include="drinks", se.fit=T)
pdrink <- predict(pssamod, newdata=data.frame(drinks=0:5), include="drinks", se.fit=T)

### plot effects
dev.new(width=12, height=8, noRStudioGD=TRUE)
layout(matrix(c(1,2,3,4,4,4),2,3,byrow=T))
par(mar=c(5,5,4,2))
mcols <- c("blue","black","mediumpurple")
scols <- c("cyan","lightgray","lavender")

### age effect
plotci(18:80, eage$fit, eage$se.fit, ylim=c(-0.1,0.1), lwd=2, level=0.9,
       cex.lab=2, cex.axis=1.5, xlab="Age (years)", ylab="Rating",
       cex.main=3, main="Age Effect",col=mcols[1], col.ci=scols[1])
plotci(18:80, gage$fit, gage$se.fit, add=T, col=mcols[2], col.ci=scols[2],
       lty=2, lwd=2, level=0.9)
plotci(18:80, page$fit, page$se.fit, add=T, col=mcols[3], col.ci=scols[3], 
       lty=3, lwd=2, level=0.9)
legend("topleft",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1:3,col=mcols,bty="n",cex=1.5)
abline(0,0,lty=3)

### gender effect
gfit <- rbind(egender$fit, ggender$fit, pgender$fit)
gsefit <- rbind(egender$se.fit, ggender$se.fit, pgender$se.fit)
plotci(1:3, gfit[,1], gsefit[,1], ylim=c(-0.1,0.1), lwd=2, xlim=c(0.5,8.5), axes=F, 
       bars=T, barlwd=2, level=0.9, type="n", col.ci=mcols,
       xlab="Gender", ylab="Rating", cex.lab=2,
       main="Gender Effect", cex.main=3, bw=0.1)
plotci(6:8, gfit[,2], gsefit[,2], add=T, bars=T, barlwd=2, level=0.9, 
       type="n", col.ci=mcols, bw=0.1)
axis(1, at=c(2,7), labels=c("Female", "Male"), cex.axis=1.5)
axis(2, cex.axis=1.5)
legend("topleft",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1,col=mcols,bty="n",cex=1.5)
abline(0,0,lty=3)
box()

### drinking effect
dfit <- rbind(edrink$fit, gdrink$fit, pdrink$fit)
dsefit <- rbind(edrink$se.fit, gdrink$se.fit, pdrink$se.fit)
plotci(1:3, dfit[,1], dsefit[,1], ylim=c(-0.1,0.1), lwd=2, 
       xlim=c(0.5,33.5), axes=F, bars=T, barlwd=2, 
       level=0.9, type="n", col.ci=mcols, xlab="Number of Drinks", 
       ylab="Rating", cex.lab=2, main="Drinks Effect", 
       cex.main=3, bw=0.5)
for(k in 2:6){
  plotci(1:3 + 6*(k-1), dfit[,k], dsefit[,k], ylim=c(-0.5,0.5), lwd=2, level=0.9, 
         bars=T, barlwd=2, type="n", col.ci=mcols, bw=0.5, add=T)
}
axis(1, at=c(2,8,14,20,26,32), labels=0:5, cex.axis=1.5)
axis(2, cex.axis=1.5)
legend("topleft",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1,col=mcols,bty="n",cex=1.5)
abline(0,0,lty=3)
box()

### smile effect
fitlist <- list(esmilefit, gsmilefit, psmilefit)
fit <- c(t(sapply(fitlist, function(x) x$fit)))
se.fit <- c(t(sapply(fitlist, function(x) x$se.fit)))
xseq <- 1:3
aseq <- 2
for(k in 2:27) {
  xseq <- c(xseq, 1:3 + (k-1)*9)
  aseq <- c(aseq, 2 + (k-1)*9)
}
barcol <- rep(mcols, 27)
plotci(xseq, fit, se.fit, level=0.9, type="n", bars=T, barlwd=2, 
       col.ci=barcol, bw=0.5, ylim=c(0.2,0.8), xlab="Stimulus Number",
       ylab="Rating",axes=F,cex=2,cex.lab=2, cex.axis=1.5, 
       main="Smile Effect", cex.main=3)
axis(1, at=aseq, labels=1:27, cex.axis=1.5)
axis(2, cex.axis=1.5)
abline(0.5,0,lty=3)
anglab <- toupper(substr(smileInfo$Angle,1,1))
denlab <- toupper(substr(smileInfo$Dental,1,1))
extlab <- toupper(substr(smileInfo$Extent,1,1))
for(k in 1:27){
  text(aseq[k], 0.2, extlab[k])
  text(aseq[k], 0.23, denlab[k])
  text(aseq[k], 0.26, anglab[k])
}
text(242, 0.2, "Extent")
text(242, 0.23, "Dental")
text(242, 0.26, "Angle")
legend("topleft",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1,col=mcols,bty="n",cex=1.5)
dev.copy2pdf(file=paste0(path,"Fig6.pdf"))


### plot fitted values (heat map)
col <- brewer.pal(10, "RdYlGn")
dev.new(width=12, height=4, noRStudioGD=TRUE)
par(mfrow=c(1,3), mar=c(5,5,4,2))
alab <- c("low","medium","high")
for(k in 1:3){
  fit <- NULL
  for(j in 1:9){
    fit <- c(fit, esmilefit$fit[j+9*(k-1)], 
             gsmilefit$fit[j+9*(k-1)], psmilefit$fit[j+9*(k-1)])
  }
  imagebar(1:9, 1:3, matrix(fit,9,3), col=col, ncolor=length(col),
           zlim=c(0.25,0.75), axes=FALSE, zaxis.at=seq(0.25,0.75,length.out=3),
           xlab="", ylab="", zlab="Rating", main=paste("Mouth Angle:",alab[k]),
           cex.lab=1.75, cex.main=1.75, zcex.lab=1.75, zcex.axis=1.25, zline=3)
  mtext("Smile Extent", 1, line=1.5, cex=1.75*par()$cex)
  mtext("Dental Show", 2, line=1.5, cex=1.75*par()$cex)
  axis(1, at=c(2,5,8), labels=alab, cex.axis=1.5, lwd=0, line=-1.5)
  axis(2, at=1:3, labels=alab, cex.axis=1.5, lwd=0, line=-1.5)
  for(xx in c(0.5,3.5,6.5,9.5)) lines(c(xx,xx), c(0.5,3.5))
  for(yy in c(0.5,1.5,2.5,3.5)) lines( c(0.5,9.5), c(yy,yy))
}
dev.copy2pdf(file=paste0(path,"Fig7.pdf"))


### plot emotions by faces probabilities
spdata = split(smiledata, f=smiledata$stimuli)
ix = match(smileInfo$stimuli,names(spdata))
spdata = spdata[ix]
emotions = sapply(spdata, function(x) colMeans(x[,c("happy","sad","anger","contempt","fear","surprise","disgust")]))
dev.new(width=12, height=8, noRStudioGD=TRUE)
par(mfrow=c(2,1))
imagebar(1:27, 1:7, t(emotions)*100, zlim=c(0,100), axes=F,
         pltimage=c(.11,.88,.11,.88),pltbar=c(.90,.93,.1,.9),
         cex.lab=1.75,cex.main=1.75,
         zcex.lab=1.75,zcex.axis=1.25,zline=3, xlab="", ylab="",
         col=brewer.pal(9, "Blues"), zlab="% Selected")
axis(1, at=1:27, line=3, cex.axis=1.5)
axis(2, at=1:7, las=2, line=-2.25, cex.axis=1.5,
     labels=c("happy","sad","anger","contempt","fear","surprise","disgust"))
imagebar(1:27, 1:6, t(emotions[-1,])*100, zlim=c(0,26), axes=F,
         pltimage=c(.11,.88,.11,.88),pltbar=c(.90,.93,.1,.9),
         cex.lab=1.75,cex.main=1.75,
         zcex.lab=1.75,zcex.axis=1.25,zline=3, xlab="", ylab="",
         col=brewer.pal(9, "Blues"), zlab="% Selected")
axis(1, at=1:27, line=3, cex.axis=1.5)
axis(2, at=1:6, las=2, line=-2.25, cex.axis=1.5,
     labels=c("sad","anger","contempt","fear","surprise","disgust"))
dev.copy2pdf(file=paste0(path,"Fig9.pdf"))


###################     DATA ANALYSIS: ASYMMETRIC SMILES     ###################

###*### get data for smile 22 with and without asymmetries ###*###

### load data
smiledata22 = read.csv(paste0(path,"smiledata22.csv"))

### plot average ratings
dev.new(width=9, height=4, noRStudioGD=TRUE)
par(mfrow=c(1,3))
plot(c(0,25,50,100,150,200),tapply(smiledata22$effective, smiledata22$delay, mean), 
     xlab="Delay Time (ms)", ylab="Rating (Raw Units)", type="b")
plot(c(0,25,50,100,150,200),tapply(smiledata22$genuine, smiledata22$delay, mean), 
     xlab="Delay Time (ms)", ylab="Rating (Raw Units)", type="b")
plot(c(0,25,50,100,150,200),tapply(smiledata22$pleasant, smiledata22$delay, mean), 
     xlab="Delay Time (ms)", ylab="Rating (Raw Units)", type="b")


###*### fit models ###*###

### get knots
set.seed(1)
ixsp = split(1:nrow(smiledata22), smiledata22$stimuli)
knotid22 = unlist(lapply(ixsp,function(x) x[1]))
knotid22 = unname(c(knotid22, binsamp(smiledata22$age,nmbin=10)))

### fit models
rktypes22 = list(age="cub",gender="nom",drinks="cub",delay="cub")
essamod22 = bigssp(effective ~ age + gender + drinks + delay, data=smiledata22, 
                   type=rktypes22, nknots=knotid22, random=~1|subID, skip.iter=FALSE)
gssamod22 = bigssp(genuine ~ age + gender + drinks + delay, data=smiledata22, 
                   type=rktypes22, nknots=knotid22, random=~1|subID, skip.iter=FALSE)
pssamod22 = bigssp(pleasant ~ age + gender + drinks + delay, data=smiledata22, 
                   type=rktypes22, nknots=knotid22, random=~1|subID, skip.iter=FALSE)

### get age effect fitted values
eage22 = predict(essamod22, newdata=data.frame(age=seq(18,80)), include="age", se.fit=T)
gage22 = predict(gssamod22, newdata=data.frame(age=seq(18,80)), include="age", se.fit=T)
page22 = predict(pssamod22, newdata=data.frame(age=seq(18,80)), include="age", se.fit=T)

### get gender effect fitted values
egender22 = predict(essamod22, newdata=data.frame(gender=c("F","M")), include="gender", se.fit=T)
ggender22 = predict(gssamod22, newdata=data.frame(gender=c("F","M")), include="gender", se.fit=T)
pgender22 = predict(pssamod22, newdata=data.frame(gender=c("F","M")), include="gender", se.fit=T)

### get drinking effect fitted values
edrink22 = predict(essamod22, newdata=data.frame(drinks=0:5), include="drinks", se.fit=T)
gdrink22 = predict(gssamod22, newdata=data.frame(drinks=0:5), include="drinks", se.fit=T)
pdrink22 = predict(pssamod22, newdata=data.frame(drinks=0:5), include="drinks", se.fit=T)

### get time delay effect fitted values
edelay = predict(essamod22, newdata=data.frame(delay=seq(0,200,length=201)), include="delay", se.fit=T)
gdelay = predict(gssamod22, newdata=data.frame(delay=seq(0,200,length=201)), include="delay", se.fit=T)
pdelay = predict(pssamod22, newdata=data.frame(delay=seq(0,200,length=201)), include="delay", se.fit=T)

### plot effects
dev.new(width=12, height=8, noRStudioGD=TRUE)
layout(matrix(c(1,2,3,4,4,4),2,3,byrow=T))
par(mar=c(5,5,4,2))
mcols = c("blue","black","mediumpurple")
scols = c("cyan","lightgray","lavender")

### age effect
plotci(18:80, eage22$fit, eage22$se.fit, ylim=c(-0.15,0.15), lwd=2, level=0.9,
       cex.lab=2, cex.axis=1.5, xlab="Age (years)", ylab="Rating",
       cex.main=3, main="Age Effect",col=mcols[1], col.ci=scols[1])
plotci(18:80, gage22$fit, gage22$se.fit, add=T, col=mcols[2], col.ci=scols[2],
       lty=2, lwd=2, level=0.9)
plotci(18:80, page22$fit, page22$se.fit, add=T, col=mcols[3], col.ci=scols[3], 
       lty=3, lwd=2, level=0.9)
legend("topleft",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1:3,col=mcols,bty="n",cex=1.5)
abline(0,0,lty=3)

### gender effect
gfit22 = rbind(egender22$fit, ggender22$fit, pgender22$fit)
gsefit22 = rbind(egender22$se.fit, ggender22$se.fit, pgender22$se.fit)
plotci(1:3, gfit22[,1], gsefit22[,1], ylim=c(-0.15,0.15), lwd=2, xlim=c(0.5,8.5), axes=F, 
       bars=T, barlwd=2, level=0.9, type="n", col.ci=mcols,
       xlab="Gender", ylab="Rating", cex.lab=2,
       main="Gender Effect", cex.main=3, bw=0.1)
plotci(6:8, gfit22[,2], gsefit22[,2], add=T, bars=T, barlwd=2, level=0.9, 
       type="n", col.ci=mcols, bw=0.1)
axis(1, at=c(2,7), labels=c("Female", "Male"), cex.axis=1.5)
axis(2, cex.axis=1.5)
legend("topleft",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1,col=mcols,bty="n",cex=1.5)
abline(0,0,lty=3)
box()

### drinking effect
dfit22 = rbind(edrink22$fit, gdrink22$fit, pdrink22$fit)
dsefit22 = rbind(edrink22$se.fit, gdrink22$se.fit, pdrink22$se.fit)
plotci(1:3, dfit22[,1], dsefit22[,1], ylim=c(-0.15,0.15), lwd=2, 
       xlim=c(0.5,33.5), axes=F, bars=T, barlwd=2, 
       level=0.9, type="n", col.ci=mcols, xlab="Number of Drinks", 
       ylab="Rating", cex.lab=2, main="Drinks Effect", 
       cex.main=3, bw=0.5)
for(k in 2:6){
  plotci(1:3 + 6*(k-1), dfit22[,k], dsefit22[,k], ylim=c(-0.5,0.5), lwd=2, level=0.9, 
         bars=T, barlwd=2, type="n", col.ci=mcols, bw=0.5, add=T)
}
axis(1, at=c(2,8,14,20,26,32), labels=0:5, cex.axis=1.5)
axis(2, cex.axis=1.5)
legend("top",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1,col=mcols,bty="n",cex=1.5)
abline(0,0,lty=3)
box()

### delay time effect
plotci(seq(0,200,length=201), edelay$fit, edelay$se.fit, ylim=c(-0.15,0.15), lwd=2, level=0.9,
       cex.lab=2, cex.axis=1.5, xlab="Delay Asymmetry (ms)", ylab="Rating",
       cex.main=3, main="Delay Effect",col=mcols[1], col.ci=scols[1])
plotci(seq(0,200,length=201), gdelay$fit, gdelay$se.fit, add=T, col=mcols[2], col.ci=scols[2],
       lty=2, lwd=2, level=0.9)
plotci(seq(0,200,length=201), pdelay$fit, pdelay$se.fit, add=T, col=mcols[3], col.ci=scols[3], 
       lty=3, lwd=2, level=0.9)
legend("bottomleft",c("Effective","Genuine","Pleasant"),lwd=rep(2,3),
       lty=1:3,col=mcols,bty="n",cex=1.5)
abline(0,0,lty=3)

dev.copy2pdf(file=paste0(path,"Fig10.pdf"))


### get individual level predictions
ehat22 = predict(essamod22) + essamod22$blup[match(smiledata22$subID,names(essamod22$blup))]
ghat22 = predict(gssamod22) + gssamod22$blup[match(smiledata22$subID,names(gssamod22$blup))]
phat22 = predict(pssamod22) + pssamod22$blup[match(smiledata22$subID,names(pssamod22$blup))]

### check R-squared without random effects
eRsqA22 = cor(smiledata22$effective,predict(essamod22))^2
gRsqA22 = cor(smiledata22$genuine,predict(gssamod22))^2
pRsqA22 = cor(smiledata22$pleasant,predict(pssamod22))^2

### check R-squared with random effects
eRsqB22 = cor(smiledata22$effective,ehat22)^2
gRsqB22 = cor(smiledata22$genuine,ghat22)^2
pRsqB22 = cor(smiledata22$pleasant,phat22)^2

### check variance parameters
evar22 = (essamod22$sigma^2)*c(1,essamod22$tau)
gvar22 = (gssamod22$sigma^2)*c(1,gssamod22$tau)
pvar22 = (pssamod22$sigma^2)*c(1,pssamod22$tau)

### check intra-class correlations
eicc22 = essamod22$tau / (1 + essamod22$tau)
gicc22 = gssamod22$tau / (1 + gssamod22$tau)
picc22 = pssamod22$tau / (1 + pssamod22$tau)

### table results
table3B = rbind(RsqA = c(eRsqA22, gRsqA22, pRsqA22),
                RsqB = c(eRsqB22, gRsqB22, pRsqB22),
                sigsq = c(evar22[1],gvar22[1],pvar22[1]),
                thesq = c(evar22[2],gvar22[2],pvar22[2]),
                icc = c(eicc22, gicc22, picc22))

### combine to form table 3
table3 = cbind(table3A, table3B)

### effect sizes (200 ms)
(edelay$fit[201]) / essamod22$sigma
(gdelay$fit[201]) / gssamod22$sigma
(pdelay$fit[201]) / pssamod22$sigma

### effect sizes (75 ms minus 200 ms)
(edelay$fit[76]-edelay$fit[201]) / essamod22$sigma
(gdelay$fit[76]-gdelay$fit[201]) / gssamod22$sigma
(pdelay$fit[76]-pdelay$fit[201]) / pssamod22$sigma

